"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toInteractiveDataFrame = toInteractiveDataFrame;
const jsdom_1 = require("jsdom");
const table_shared_1 = require("./table-shared");
/**
 * toInteractiveDataFrame requires the page, dataTestId of the table
 * and the headers in the order they appear on the table.
 *
 * The result will be rows of tableCells for each column.
 * The table cell will contain a key:value, which can be used for the
 * PW Locator. Use `enterByKey` to enter values into a table cell.
 *
 * @example
 *
 * | one | two |   |
 * | a   | b   | X |
 * | c   | 1   | Y |
 *
 * headers = ["one", "two", "*three"]
 *
 * toInteractiveDataFrame(page, "table-id", headers)
 *
 * @param page
 * @param dataTestId
 * @param headers
 * @returns
 */
function toInteractiveDataFrame(html, headers) {
    const dom = new jsdom_1.JSDOM(html);
    const document = dom.window.document;
    // Look for the tbody instead of the entire document
    const tbody = document.querySelector('tbody');
    if (!tbody) {
        throw new Error('No <tbody> element found in the HTML.');
    }
    // Generate headers based on the table's structure or validate existing ones
    if (!headers || headers.length === 0) {
        headers = (0, table_shared_1.generateHeaders)(document);
    }
    else {
        (0, table_shared_1.validateHeaders)(headers, document);
    }
    // Focus on rows inside the tbody
    const rows = Array.from(tbody.querySelectorAll('tr')).map((row) => {
        return Array.from(row.querySelectorAll('td')).map((cell) => {
            const queryOnElements = 'textarea, input, button, mat-select, mat-icon, mat-slide-toggle, select';
            const control = cell.querySelector(queryOnElements);
            if (control) {
                let type = '';
                // Determine the type based on the tagName
                if (control.tagName === 'SELECT') {
                    type = 'select';
                }
                else if (control.tagName === 'TEXTAREA') {
                    type = 'textarea';
                }
                else if (control.tagName === 'INPUT') {
                    type = 'input';
                }
                // Use extractLocatorID to get all attributes
                return extractLocatorID(control, type);
            }
            // Return a LocatorID for cells without controls
            return extractLocatorID(cell, 'unknown');
        });
    });
    return (0, table_shared_1.buildData)(rows, headers);
}
/**
 * Extracts all attributes from a DOM element.
 *
 * @param element - The DOM element from which to extract the attributes.
 * @param type - The type of the element (e.g., 'select', 'input', 'textarea').
 * @returns A LocatorID object containing all attributes as key-value pairs and the element type.
 */
function extractLocatorID(element, type) {
    const attributes = {};
    // Extract all attributes as key-value pairs
    Array.from(element.attributes).forEach((attr) => {
        attributes[attr.name] = attr.value;
    });
    return {
        attributes,
        type: type || 'unknown',
    };
}
